"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tiny_controllers_1 = require("tiny-controllers");
class TinyRouters {
    constructor(options) {
        this._allRoutes = ['find', 'get', 'post', 'put', 'delete'];
        this._tinyController = new tiny_controllers_1.TinyControllers(options.model);
        this._router = options.router;
    }
    all(middlewares) {
        this.find(middlewares);
        this.get(middlewares);
        this.post(middlewares);
        this.put(middlewares);
        this.delete(middlewares);
    }
    only(routes) {
        if (routes && Array.isArray(routes) && routes.length > 0) {
            routes.forEach(route => this.add(route));
        }
    }
    find(middlewares) {
        if (middlewares) {
            this._router.get('/', middlewares, (req, res, next) => this._tinyController.doFind(req, res, next));
        }
        else {
            this._router.get('/', (req, res, next) => this._tinyController.doFind(req, res, next));
        }
    }
    get(middlewares) {
        if (middlewares) {
            this._router.get('/:id', middlewares, (req, res, next) => this._tinyController.doGet(req, res, next));
        }
        else {
            this._router.get('/:id', (req, res, next) => this._tinyController.doGet(req, res, next));
        }
    }
    post(middlewares) {
        if (middlewares) {
            this._router.post('/', middlewares, (req, res, next) => this._tinyController.doPost(req, res, next));
        }
        else {
            this._router.post('/', (req, res, next) => this._tinyController.doPost(req, res, next));
        }
    }
    put(middlewares) {
        if (middlewares) {
            this._router.put('/:id', middlewares, (req, res, next) => this._tinyController.doPut(req, res, next));
        }
        else {
            this._router.put('/:id', (req, res, next) => this._tinyController.doPut(req, res, next));
        }
    }
    delete(middlewares) {
        if (middlewares) {
            this._router.delete('/:id', middlewares, (req, res, next) => this._tinyController.doDelete(req, res, next));
        }
        else {
            this._router.delete('/:id', (req, res, next) => this._tinyController.doDelete(req, res, next));
        }
    }
    add(route) {
        if (typeof route === 'string') {
            this[route]();
        }
        else {
            this[route.name](route.middlewares);
        }
    }
}
exports.TinyRouters = TinyRouters;
